#!/usr/bin/env node
'use strict';

var _blessed = require('blessed');

var _blessed2 = _interopRequireDefault(_blessed);

var _pipboylib = require('pipboylib');

var _rx = require('rx');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var discover = _pipboylib.connection.discover;
var createSocket = _pipboylib.connection.createSocket;
var sendPeriodicHeartbeat = _pipboylib.connection.sendPeriodicHeartbeat;
var createConnectionSubject = _pipboylib.connection.createConnectionSubject;
var parseBinaryMap = _pipboylib.decoding.parseBinaryMap;
var parseBinaryDatabase = _pipboylib.decoding.parseBinaryDatabase;
var aggregateBundles = _pipboylib.decoding.aggregateBundles;
var generateTreeFromDatabase = _pipboylib.decoding.generateTreeFromDatabase;
var connected = _pipboylib.status.connected;
var channels = _pipboylib.constants.channels;

var launchCli = function launchCli(subject) {
  connected(subject).then(function (handshake) {
    /**
     * Rendering the screen.
     */
    var screen = _blessed2.default.screen({
      autoPadding: true,
      smartCSR: true,
      title: 'PipBoy'
    });

    var hpMeter = _blessed2.default.progressbar({
      label: 'HP',
      top: "60%",
      left: "60%",
      width: "40%",
      height: "10%",
      border: {
        type: 'line'
      },
      style: {
        border: {
          fg: 'green'
        },
        bar: {
          bg: 'green'
        }
      }
    });
    screen.append(hpMeter);

    screen.key(['escape', 'q', 'C-c'], function (ch, key) {
      return process.exit(0);
    });

    var database = subject.filter(function (x) {
      return x.type === channels.DatabaseUpdate;
    }).map(function (x) {
      return parseBinaryDatabase(x.payload);
    }).scan(aggregateBundles, {}).map(function (x) {
      return generateTreeFromDatabase(x);
    });

    var playerInfo = database.map(function (x) {
      return x.PlayerInfo;
    });

    playerInfo.map(function (p) {
      return p.PlayerName;
    }).distinctUntilChanged().subscribe(function (name) {
      screen.title = 'PipBoy - ' + name;
    });

    playerInfo.map(function (x) {
      return { CurrHP: x.CurrHP, MaxHP: x.MaxHP };
    }).distinctUntilChanged().subscribe(function (p) {
      var percent = 0;
      if (p.MaxHP > 0) {
        percent = p.CurrHP / p.MaxHP;
      }
      hpMeter.label = 'HP - ' + p.CurrHP;
      hpMeter.filled = percent * 100;
      screen.render();
    });
  }).catch(function (err) {
    console.error('Couldn\'t establish connection!', err);
    console.error(err.stack);
    throw err;
  });
};

discover().then(function (server) {
  return createSocket(server.info.address);
}).then(function (socket) {
  sendPeriodicHeartbeat(socket);
  return createConnectionSubject(socket);
}).then(launchCli).catch(function (err) {
  throw err;
});
//# sourceMappingURL=index.js.map